@@ -1,41 +1,9 @@
-#' @title Coloured console output
-#' @name print_color
-#'
-#' @description Convenient function that allows coloured output in the console.
-#'  Mainly implemented to reduce package dependencies.
-#'
-#' @param text The text to print.
-#' @param color,colour Character vector, indicating the colour for printing.
-#'   May be one of \code{"red"}, \code{"yellow"}, \code{"green"}, \code{"blue"},
-#'   \code{"violet"}, \code{"cyan"} or \code{"grey"}. Formatting is also possible
-#'   with \code{"bold"} or \code{"italic"}.
-#'
-#' @details This function prints \code{text} directly to the console using
-#'   \code{cat()}, so no string is returned.
-#'
-#' @return Nothing.
-#'
-#' @examples
-#' print_color("I'm blue dabedi dabedei", "blue")
-#'
-#' @export
-print_color <- function(text, color) {
-  cat(.colour(colour = color, x = text))
-}
-
-#' @rdname print_color
-#' @export
-print_colour <- function(text, colour) {
-  print_color(color = colour, text = text)
-}
-
-
 .rstudio_with_ansi_support <- function() {
   if (Sys.getenv("RSTUDIO", "") == "") {
     return(FALSE)
   }
   if ((cols <- Sys.getenv("RSTUDIO_CONSOLE_COLOR", "")) !=
-      "" && !is.na(as.numeric(cols))) {
+    "" && !is.na(as.numeric(cols))) {
     return(TRUE)
   }
   requireNamespace("rstudioapi", quietly = TRUE) && rstudioapi::isAvailable() &&
@@ -70,7 +38,7 @@ print_colour <- function(text, colour) {
     return(FALSE)
   }
   grepl("^screen|^xterm|^vt100|color|ansi|cygwin|linux", Sys.getenv("TERM"),
-        ignore.case = TRUE, perl = TRUE
+    ignore.case = TRUE, perl = TRUE
   )
 }
 
@@ -141,8 +109,7 @@ print_colour <- function(text, colour) {
 
 
 .colour <- function(colour = "red", x) {
-  switch(
-    colour,
+  switch(colour,
     red = .red(x),
     yellow = .yellow(x),
     green = .green(x),
@@ -155,3 +122,8 @@ print_colour <- function(text, colour) {
     warning(paste0("`color` ", colour, " not yet supported."))
   )
 }
+
+
+.is_valid_colour <- function(colour) {
+  colour %in% c("red", "yellow", "green", "blue", "violet", "cyan", "grey", "bold", "italic")
+}
