@@ -1,5 +1,10 @@
 #' @importFrom stats nobs
-.compute_variances <- function(x, component, name_fun = NULL, name_full = NULL, verbose = TRUE, tolerance = 1e-5) {
+.compute_variances <- function(x,
+                               component,
+                               name_fun = NULL,
+                               name_full = NULL,
+                               verbose = TRUE,
+                               tolerance = 1e-5) {
 
   ## Original code taken from GitGub-Repo of package glmmTMB
   ## Author: Ben Bolker, who used an cleaned-up/adapted
@@ -12,7 +17,7 @@
 
   if (faminfo$family %in% c("truncated_nbinom1")) {
     if (verbose) {
-      warning(sprintf("Truncated negative binomial families are currently not supported by `%s`.", name_fun), call. = F)
+      warning(sprintf("Truncated negative binomial families are currently not supported by `%s`.", name_fun), call. = FALSE)
     }
     return(NA)
   }
@@ -25,7 +30,7 @@
   no_random_variance <- FALSE
   if (.is_singular(x, vals, tolerance = tolerance) && !(component %in% c("slope", "intercept"))) {
     if (verbose) {
-      warning(sprintf("Can't compute %s. Some variance components equal zero. Your model may suffer from singulariy.\n  Solution: Respecify random structure!\n  You may also decrease the 'tolerance' level to enforce the calculation of random effect variances.", name_full), call. = F)
+      warning(sprintf("Can't compute %s. Some variance components equal zero. Your model may suffer from singulariy.\n  Solution: Respecify random structure!\n  You may also decrease the 'tolerance' level to enforce the calculation of random effect variances.", name_full), call. = FALSE)
     }
     no_random_variance <- TRUE
   }
@@ -57,7 +62,7 @@
   obs.terms <- names(nr[nr == n_obs(x)])
 
   # Variance of random effects
-  if (component %in% c("random", "all") && !isTRUE(no_random_variance)) {
+  if (component %in% c("random", "all") && isFALSE(no_random_variance)) {
     var.random <- .compute_variance_random(not.obs.terms, x = x, vals = vals)
   }
 
@@ -65,11 +70,22 @@
   # additive dispersion and the distribution-specific variance (Johnson et al. 2014)
 
   if (component %in% c("residual", "distribution", "all")) {
-    var.distribution <- .compute_variance_distribution(x, var.cor = vals$vc, faminfo, name = name_full, verbose = verbose)
+    var.distribution <- .compute_variance_distribution(
+      x = x,
+      var.cor = vals$vc,
+      faminfo,
+      name = name_full,
+      verbose = verbose
+    )
   }
 
   if (component %in% c("residual", "dispersion", "all")) {
-    var.dispersion <- .compute_variance_dispersion(x = x, vals = vals, faminfo = faminfo, obs.terms = obs.terms)
+    var.dispersion <- .compute_variance_dispersion(
+      x = x,
+      vals = vals,
+      faminfo = faminfo,
+      obs.terms = obs.terms
+    )
   }
 
   if (component %in% c("residual", "all")) {
@@ -367,8 +383,7 @@
     dist.variance <- sig^2
   } else {
     if (faminfo$is_betabinomial) {
-      dist.variance <- switch(
-        faminfo$link_function,
+      dist.variance <- switch(faminfo$link_function,
         logit = ,
         probit = ,
         cloglog = ,
@@ -376,8 +391,7 @@
         .badlink(faminfo$link_function, faminfo$family, verbose = verbose)
       )
     } else if (faminfo$is_binomial) {
-      dist.variance <- switch(
-        faminfo$link_function,
+      dist.variance <- switch(faminfo$link_function,
         logit = pi^2 / 3,
         probit = 1,
         cloglog = ,
@@ -385,16 +399,14 @@
         .badlink(faminfo$link_function, faminfo$family, verbose = verbose)
       )
     } else if (faminfo$is_count) {
-      dist.variance <- switch(
-        faminfo$link_function,
+      dist.variance <- switch(faminfo$link_function,
         log = .variance_distributional(x, faminfo, sig, name = name, verbose = verbose),
         sqrt = 0.25,
         .badlink(faminfo$link_function, faminfo$family, verbose = verbose)
       )
     } else if (faminfo$family %in% c("Gamma", "gamma")) {
       ## TODO needs some more checking - should now be in line with other packages
-      dist.variance <- switch(
-        faminfo$link_function,
+      dist.variance <- switch(faminfo$link_function,
         inverse = ,
         identity = ,
         log = stats::family(x)$variance(sig),
@@ -402,14 +414,12 @@
         .badlink(faminfo$link_function, faminfo$family, verbose = verbose)
       )
     } else if (faminfo$family == "beta") {
-      dist.variance <- switch(
-        faminfo$link_function,
+      dist.variance <- switch(faminfo$link_function,
         logit = .variance_distributional(x, faminfo, sig, name = name, verbose = verbose),
         .badlink(faminfo$link_function, faminfo$family, verbose = verbose)
       )
     } else if (faminfo$is_tweedie) {
-      dist.variance <- switch(
-        faminfo$link_function,
+      dist.variance <- switch(faminfo$link_function,
         log = .variance_distributional(x, faminfo, sig, name = name, verbose = verbose),
         .badlink(faminfo$link_function, faminfo$family, verbose = verbose)
       )
@@ -477,7 +487,7 @@
 
   if (is.na(mu)) {
     if (verbose) {
-      warning("Can't calculate model's distribution-specific variance. Results are not reliable.", call. = F)
+      warning("Can't calculate model's distribution-specific variance. Results are not reliable.", call. = FALSE)
     }
     return(0)
   }
@@ -489,8 +499,7 @@
 
   cvsquared <- tryCatch(
     {
-      vv <- switch(
-        faminfo$family,
+      vv <- switch(faminfo$family,
 
         # (zero-inflated) poisson ----
         `zero-inflated poisson` = ,
@@ -522,13 +531,13 @@
       )
 
       if (vv < 0 && isTRUE(verbose)) {
-        warning("Model's distribution-specific variance is negative. Results are not reliable.", call. = F)
+        warning("Model's distribution-specific variance is negative. Results are not reliable.", call. = FALSE)
       }
       vv / mu^2
     },
     error = function(x) {
       if (verbose) {
-        warning("Can't calculate model's distribution-specific variance. Results are not reliable.", call. = F)
+        warning("Can't calculate model's distribution-specific variance. Results are not reliable.", call. = FALSE)
       }
       0
     }
@@ -626,8 +635,7 @@
     mu <- stats::predict(model, type = "conditional")
     # sigma
     betad <- model$fit$par["betad"]
-    k <- switch(
-      faminfo$family,
+    k <- switch(faminfo$family,
       gaussian = exp(0.5 * betad),
       Gamma = exp(-0.5 * betad),
       exp(betad)
@@ -648,7 +656,7 @@
   # pearson residuals
   # pred <- predict(model, type = "response") ## (1 - p) * mu
   # pred <- stats::predict(model, type_pred = "response", type = "mean_subject")
-  # (insight::get_response(model) - pred) / sqrt(pvar)
+  # (get_response(model) - pred) / sqrt(pvar)
 }
 
 
@@ -703,7 +711,7 @@
     },
     error = function(x) {
       if (verbose) {
-        warning("Can't calculate model's distribution-specific variance. Results are not reliable.", call. = F)
+        warning("Can't calculate model's distribution-specific variance. Results are not reliable.", call. = FALSE)
       }
       0
     }
