@@ -16,10 +16,10 @@
 #'      \item \code{zero_inflated}, the "fixed effects" part from the zero-inflation component of the model
 #'      \item \code{zero_inflated_random}, the "random effects" part from the zero-inflation component of the model
 #'      \item \code{dispersion}, the dispersion formula
-#'      \item \code{instruments}, for fixed-effects regressions like \code{ivreg}, \code{felm} or \code{plm}, the instrumental variables
-#'      \item \code{cluster}, for fixed-effects regressions like \code{felm}, the cluster specification
-#'      \item \code{correlation}, for models with correlation-component like \code{gls}, the formula that describes the correlation structure
-#'      \item \code{slopes}, for fixed-effects individual-slope models like \code{feis}, the formula for the slope parameters
+#'      \item \code{instruments}, for fixed-effects regressions like \code{ivreg::ivreg()}, \code{lfe::felm()} or \code{plm::plm()}, the instrumental variables
+#'      \item \code{cluster}, for fixed-effects regressions like \code{lfe::felm()}, the cluster specification
+#'      \item \code{correlation}, for models with correlation-component like \code{nlme::gls()}, the formula that describes the correlation structure
+#'      \item \code{slopes}, for fixed-effects individual-slope models like \code{feisr::feis()}, the formula for the slope parameters
 #'      \item \code{precision}, for \code{DirichletRegModel} models from \pkg{DirichletReg}, when parametrization (i.e. \code{model}) is \code{"alternative"}.
 #'    }
 #'
@@ -31,6 +31,13 @@
 #' data(mtcars)
 #' m <- lm(mpg ~ wt + cyl + vs, data = mtcars)
 #' find_formula(m)
+#'
+#' if (require("lme4")) {
+#'   m <- lmer(Sepal.Length ~ Sepal.Width + (1 | Species), data = iris)
+#'   f <- find_formula(m)
+#'   f
+#'   format(f)
+#' }
 #' @importFrom stats formula terms as.formula
 #' @export
 find_formula <- function(x, ...) {
@@ -44,12 +51,7 @@ find_formula <- function(x, ...) {
 
 #' @export
 find_formula.default <- function(x, ...) {
-  if (inherits(x, "list") && .obj_has_name(x, "gam")) {
-    x <- x$gam
-    class(x) <- c(class(x), c("glm", "lm"))
-  }
-
-  tryCatch(
+  f <- tryCatch(
     {
       list(conditional = stats::formula(x))
     },
@@ -57,13 +59,36 @@ find_formula.default <- function(x, ...) {
       NULL
     }
   )
+  .find_formula_return(f)
+}
+
+
+
+#' @export
+find_formula.list <- function(x, ...) {
+  if (.obj_has_name(x, "gam")) {
+    if ("mer" %in% names(x)) {
+      f.random <- .fix_gamm4_random_effect(find_formula(x$mer)$random)
+      if (length(f.random) == 1) {
+        f.random <- f.random[[1]]
+      } else if (length(f.random) == 0) {
+        f.random <- NULL
+      }
+    }
+    x <- x$gam
+    class(x) <- c(class(x), c("glm", "lm"))
+    f <- .compact_list(list(conditional = stats::formula(x), random = f.random))
+  } else {
+    f <- find_formula.default(x, ...)
+  }
+  .find_formula_return(f)
 }
 
 
 
 #' @export
 find_formula.data.frame <- function(x, ...) {
-  stop("A data frame is no valid object for this function")
+  stop("A data frame is not a valid object for this function.")
 }
 
 
@@ -72,7 +97,7 @@ find_formula.data.frame <- function(x, ...) {
 find_formula.aovlist <- function(x, ...) {
   f <- attr(x, "terms", exact = TRUE)
   attributes(f) <- NULL
-  list(conditional = f)
+  .find_formula_return(list(conditional = f))
 }
 
 
@@ -119,14 +144,14 @@ find_formula.gam <- function(x, ...) {
     }
   }
 
-  f
+  .find_formula_return(f)
 }
 
 
 
 #' @export
 find_formula.gamlss <- function(x, ...) {
-  tryCatch(
+  f <- tryCatch(
     {
       f.random <- lapply(.findbars(x$mu.formula), function(.x) {
         f <- .safe_deparse(.x)
@@ -149,6 +174,7 @@ find_formula.gamlss <- function(x, ...) {
       NULL
     }
   )
+  .find_formula_return(f)
 }
 
 
@@ -158,19 +184,41 @@ find_formula.gamlss <- function(x, ...) {
 find_formula.bamlss <- function(x, ...) {
   f <- stats::formula(x)
 
-  .compact_list(list(
-    conditional = stats::as.formula(.safe_deparse(f$mu$formula)),
-    sigma = stats::as.formula(paste0("~", as.character(f$sigma$formula)[3]))
+  if (!is.null(f$mu)) {
+    f.cond <- f$mu$formula
+  } else if (!is.null(f$pi)) {
+    f.cond <- f$pi$formula
+  }
+
+  if (!is.null(f$sigma)) {
+    f.sigma <- stats::as.formula(paste0("~", as.character(f$sigma$formula)[3]))
+  } else if (!is.null(f$pi)) {
+    f.sigma <- NULL
+  }
+
+  f <- .compact_list(list(
+    conditional = stats::as.formula(.safe_deparse(f.cond)),
+    sigma = f.sigma
   ))
+  .find_formula_return(f)
 }
 
 
 
 #' @export
 find_formula.gamm <- function(x, ...) {
-  x <- x$gam
-  class(x) <- c(class(x), c("glm", "lm"))
-  NextMethod()
+  f <- .compact_list(find_formula(x$gam))
+  random <- .fix_gamm_random_effect(names(x$lme$groups))
+
+  if (length(random) == 0) {
+    f.random <- NULL
+  } else if (length(random) > 1) {
+    f.random <- lapply(random, function(r) stats::as.formula(paste0("~1|", r)))
+  } else {
+    f.random <- stats::as.formula(paste0("~1|", random))
+  }
+
+  .find_formula_return(.compact_list(c(f, list(random = f.random))))
 }
 
 
@@ -207,12 +255,30 @@ find_formula.meta_bma <- find_formula.rma
 # Other models ----------------------------------------------
 
 
+#' @export
+find_formula.censReg <- find_formula.default
+
+#' @export
+find_formula.maxLik <- find_formula.default
+
+#' @export
+find_formula.maxim <- find_formula.default
+
+
+#' @export
+find_formula.btergm <- function(x, ...) {
+  f <- list(conditional = x@formula)
+  .find_formula_return(f)
+}
+
+
 #' @export
 find_formula.mediate <- function(x, ...) {
-  list(
+  f <- list(
     mediator = find_formula(x$model.m),
     outcome = find_formula(x$model.y)
   )
+  .find_formula_return(f)
 }
 
 
@@ -233,13 +299,13 @@ find_formula.averaging <- function(x, ...) {
     f$random <- f_random$random
   }
 
-  f
+  .find_formula_return(f)
 }
 
 
 #' @export
 find_formula.glht <- function(x, ...) {
-  list(conditional = stats::formula(x$model))
+  .find_formula_return(list(conditional = stats::formula(x$model)))
 }
 
 
@@ -250,13 +316,14 @@ find_formula.betareg <- function(x, ...) {
 
   if (grepl("|", fs, fixed = TRUE)) {
     fs <- trimws(unlist(strsplit(fs, "|", fixed = TRUE)))
-    list(
+    f <- list(
       conditional = stats::as.formula(fs[1]),
       precision = stats::as.formula(paste0("~", fs[2]))
     )
   } else {
-    list(conditional = f)
+    f <- list(conditional = f)
   }
+  .find_formula_return(f)
 }
 
 
@@ -272,13 +339,13 @@ find_formula.afex_aov <- function(x, ...) {
 
 #' @export
 find_formula.mira <- function(x, ...) {
-  find_formula(x$analyses[[1]])
+  .find_formula_return(find_formula(x$analyses[[1]]))
 }
 
 
 #' @export
 find_formula.gee <- function(x, ...) {
-  tryCatch(
+  f <- tryCatch(
     {
       id <- parse(text = .safe_deparse(x$call))[[1]]$id
 
@@ -295,16 +362,18 @@ find_formula.gee <- function(x, ...) {
       NULL
     }
   )
+  .find_formula_return(f)
 }
 
 
 
 #' @export
 find_formula.MANOVA <- function(x, ...) {
-  .compact_list(list(
+  f <- .compact_list(list(
     conditional = x$input$formula,
     random = stats::as.formula(paste0("~", x$input$subject))
   ))
+  .find_formula_return(f)
 }
 
 #' @export
@@ -339,14 +408,14 @@ find_formula.gls <- function(x, ...) {
     }
   )
 
-  .compact_list(l)
+  .find_formula_return(.compact_list(l))
 }
 
 
 
 #' @export
 find_formula.LORgee <- function(x, ...) {
-  tryCatch(
+  f <- tryCatch(
     {
       id <- parse(text = .safe_deparse(x$call))[[1]]$id
 
@@ -363,13 +432,14 @@ find_formula.LORgee <- function(x, ...) {
       NULL
     }
   )
+  .find_formula_return(f)
 }
 
 
 
 #' @export
 find_formula.cglm <- function(x, ...) {
-  tryCatch(
+  f <- tryCatch(
     {
       id <- parse(text = .safe_deparse(x$call))[[1]]$id
 
@@ -386,6 +456,7 @@ find_formula.cglm <- function(x, ...) {
       NULL
     }
   )
+  .find_formula_return(f)
 }
 
 
@@ -438,7 +509,7 @@ find_formula.probitmfx <- find_formula.logitmfx
 
 #' @export
 find_formula.ivreg <- function(x, ...) {
-  tryCatch(
+  f <- tryCatch(
     {
       f <- .safe_deparse(stats::formula(x))
       cond <- .trim(substr(f, start = 0, stop = regexpr(pattern = "\\|", f) - 1))
@@ -453,18 +524,21 @@ find_formula.ivreg <- function(x, ...) {
       NULL
     }
   )
+  .find_formula_return(f)
 }
 
 
-
 #' @export
 find_formula.iv_robust <- find_formula.ivreg
 
 
+#' @export
+find_formula.ivFixed <- find_formula.ivreg
+
 
 #' @export
 find_formula.plm <- function(x, ...) {
-  tryCatch(
+  f <- tryCatch(
     {
       f <- .safe_deparse(stats::formula(x))
       bar_pos <- regexpr(pattern = "\\|", f)
@@ -493,6 +567,7 @@ find_formula.plm <- function(x, ...) {
       NULL
     }
   )
+  .find_formula_return(f)
 }
 
 
@@ -522,12 +597,13 @@ find_formula.felm <- function(x, ...) {
     f.clus <- NULL
   }
 
-  .compact_list(list(
+  f <- .compact_list(list(
     conditional = stats::as.formula(f.cond),
     random = stats::as.formula(f.rand),
     instruments = stats::as.formula(f.instr),
     cluster = stats::as.formula(f.clus)
   ))
+  .find_formula_return(f)
 }
 
 
@@ -551,11 +627,12 @@ find_formula.feglm <- function(x, ...) {
     f.clus <- NULL
   }
 
-  .compact_list(list(
+  f <- .compact_list(list(
     conditional = stats::as.formula(f.cond),
     instruments = stats::as.formula(f.instr),
     cluster = stats::as.formula(f.clus)
   ))
+  .find_formula_return(f)
 }
 
 
@@ -576,10 +653,11 @@ find_formula.fixest <- function(x, ...) {
     }
   }
 
-  .compact_list(list(
+  f <- .compact_list(list(
     conditional = stats::as.formula(f.cond),
     cluster = stats::as.formula(f.clus)
   ))
+  .find_formula_return(f)
 }
 
 
@@ -602,11 +680,12 @@ find_formula.feis <- function(x, ...) {
     f.slopes <- NULL
   }
 
-  .compact_list(list(
+  f <- .compact_list(list(
     conditional = stats::as.formula(f.cond),
     slopes = stats::as.formula(f.slopes),
     random = stats::as.formula(paste0("~", id))
   ))
+  .find_formula_return(f)
 }
 
 
@@ -624,10 +703,18 @@ find_formula.bife <- function(x, ...) {
     f.rand <- NULL
   }
 
-  .compact_list(list(
+  f <- .compact_list(list(
     conditional = stats::as.formula(f.cond),
     random = stats::as.formula(f.rand)
   ))
+  .find_formula_return(f)
+}
+
+
+
+#' @export
+find_formula.ivprobit <- function(x, ...) {
+  NULL
 }
 
 
@@ -671,12 +758,13 @@ find_formula.wbm <- function(x, ...) {
     f.clint <- NULL
   }
 
-  .compact_list(list(
+  f <- .compact_list(list(
     conditional = stats::as.formula(f.cond),
     instruments = stats::as.formula(f.instr),
     interactions = stats::as.formula(f.clint),
     random = f.rand
   ))
+  .find_formula_return(f)
 }
 
 #' @export
@@ -685,17 +773,18 @@ find_formula.wbgee <- find_formula.wbm
 
 #' @export
 find_formula.glimML <- function(x, ...) {
-  .compact_list(list(
+  f <- .compact_list(list(
     conditional = x@formula,
     random = x@random
   ))
+  .find_formula_return(f)
 }
 
 
 
 #' @export
 find_formula.tobit <- function(x, ...) {
-  tryCatch(
+  f <- tryCatch(
     {
       list(conditional = parse(text = .safe_deparse(x$call))[[1]]$formula)
     },
@@ -703,6 +792,7 @@ find_formula.tobit <- function(x, ...) {
       NULL
     }
   )
+  .find_formula_return(f)
 }
 
 
@@ -743,21 +833,23 @@ find_formula.zcpglm <- function(x, ...) {
 #' @importFrom stats as.formula
 #' @export
 find_formula.clmm2 <- function(x, ...) {
-  .compact_list(list(
+  f <- .compact_list(list(
     conditional = stats::as.formula(.safe_deparse(attr(x$location, "terms", exact = TRUE))),
     scale = stats::as.formula(.safe_deparse(attr(x$scale, "terms", exact = TRUE))),
     random = stats::as.formula(paste0("~", parse(text = .safe_deparse(x$call))[[1]]$random))
   ))
+  .find_formula_return(f)
 }
 
 
 #' @importFrom stats formula
 #' @export
 find_formula.clm2 <- function(x, ...) {
-  .compact_list(list(
+  f <- .compact_list(list(
     conditional = stats::formula(attr(x$location, "terms", exact = TRUE)),
     scale = stats::formula(attr(x$scale, "terms", exact = TRUE))
   ))
+  .find_formula_return(f)
 }
 
 
@@ -790,7 +882,7 @@ find_formula.DirichletRegModel <- function(x, ...) {
     if (length(out) == 2) names(out)[2] <- "precision"
   }
 
-  out
+  .find_formula_return(out)
 }
 
 
@@ -849,13 +941,14 @@ find_formula.glmmTMB <- function(x, ...) {
   f.cond <- stats::as.formula(.get_fixed_effects(f.cond))
   if (!is.null(f.zi)) f.zi <- stats::as.formula(.get_fixed_effects(f.zi))
 
-  .compact_list(list(
+  f <- .compact_list(list(
     conditional = f.cond,
     random = f.random,
     zero_inflated = f.zi,
     zero_inflated_random = f.zirandom,
     dispersion = f.disp
   ))
+  .find_formula_return(f)
 }
 
 
@@ -874,11 +967,12 @@ find_formula.nlmerMod <- function(x, ...) {
   f.cond <- .nobars(stats::as.formula(gsub("(.*)(~)(.*)~(.*)", "\\1\\2\\4", .safe_deparse(stats::formula(x)))))
   f.nonlin <- stats::as.formula(paste0("~", .trim(gsub("(.*)~(.*)~(.*)", "\\2", .safe_deparse(stats::formula(x))))))
 
-  .compact_list(list(
+  f <- .compact_list(list(
     conditional = f.cond,
     nonlinear = f.nonlin,
     random = f.random
   ))
+  .find_formula_return(f)
 }
 
 
@@ -896,7 +990,8 @@ find_formula.merMod <- function(x, ...) {
   }
 
   f.cond <- stats::as.formula(.get_fixed_effects(f.cond))
-  .compact_list(list(conditional = f.cond, random = f.random))
+  f <- .compact_list(list(conditional = f.cond, random = f.random))
+  .find_formula_return(f)
 }
 
 #' @export
@@ -947,7 +1042,8 @@ find_formula.sem <- function(x, ...) {
   }
 
   f.cond <- stats::as.formula(.get_fixed_effects(f.cond))
-  .compact_list(list(conditional = f.cond, random = f.random))
+  f <- .compact_list(list(conditional = f.cond, random = f.random))
+  .find_formula_return(f)
 }
 
 
@@ -963,11 +1059,12 @@ find_formula.lme <- function(x, ...) {
     fc <- NULL
   }
 
-  .compact_list(list(
+  f <- .compact_list(list(
     conditional = fm,
     random = fmr,
     correlation = stats::as.formula(fc)
   ))
+  .find_formula_return(f)
 }
 
 
@@ -978,10 +1075,11 @@ find_formula.lqmm <- function(x, ...) {
   fmr <- .safe_deparse(x$call$random)
   fmg <- .safe_deparse(x$call$group)
 
-  .compact_list(list(
+  f <- .compact_list(list(
     conditional = fm,
     random = stats::as.formula(paste0(fmr, "|", fmg))
   ))
+  .find_formula_return(f)
 }
 
 
@@ -1002,10 +1100,11 @@ find_formula.mixor <- function(x, ...) {
 
   fmr <- stats::as.formula(paste("~", fmr))
 
-  .compact_list(list(
+  f <- .compact_list(list(
     conditional = fm,
     random = fmr
   ))
+  .find_formula_return(f)
 }
 
 
@@ -1017,12 +1116,13 @@ find_formula.MixMod <- function(x, ...) {
   f.random <- stats::formula(x, type = "random")
   f.zirandom <- stats::formula(x, type = "zi_random")
 
-  .compact_list(list(
+  f <- .compact_list(list(
     conditional = f.cond,
     random = f.random,
     zero_inflated = f.zi,
     zero_inflated_random = f.zirandom
   ))
+  .find_formula_return(f)
 }
 
 
@@ -1032,17 +1132,18 @@ find_formula.BBmm <- function(x, ...) {
   f.cond <- parse(text = .safe_deparse(x$call))[[1]]$fixed.formula
   f.rand <- parse(text = .safe_deparse(x$call))[[1]]$random.formula
 
-  .compact_list(list(
+  f <- .compact_list(list(
     conditional = stats::as.formula(f.cond),
     random = stats::as.formula(f.rand)
   ))
+  .find_formula_return(f)
 }
 
 
 
 #' @export
 find_formula.mmclogit <- function(x, ...) {
-  tryCatch(
+  f <- tryCatch(
     {
       list(
         conditional = stats::formula(x),
@@ -1053,6 +1154,7 @@ find_formula.mmclogit <- function(x, ...) {
       NULL
     }
   )
+  .find_formula_return(f)
 }
 
 
@@ -1068,7 +1170,8 @@ find_formula.glmm <- function(x, ...) {
     f.random <- f.random[[1]]
   }
 
-  .compact_list(list(conditional = f.cond, random = f.random))
+  f <- .compact_list(list(conditional = f.cond, random = f.random))
+  .find_formula_return(f)
 }
 
 
@@ -1125,7 +1228,8 @@ find_formula.stanreg <- function(x, ...) {
     }
 
     f.cond <- stats::as.formula(.get_fixed_effects(f.cond))
-    .compact_list(list(conditional = f.cond, random = f.random))
+    f <- .compact_list(list(conditional = f.cond, random = f.random))
+    .find_formula_return(f)
   }
 }
 
@@ -1138,10 +1242,11 @@ find_formula.brmsfit <- function(x, ...) {
   if (.obj_has_name(f, "forms")) {
     mv_formula <- lapply(f$forms, .get_brms_formula)
     attr(mv_formula, "is_mv") <- "1"
-    mv_formula
+    f <- mv_formula
   } else {
-    .get_brms_formula(f)
+    f <- .get_brms_formula(f)
   }
+  .find_formula_return(f)
 }
 
 
@@ -1151,7 +1256,7 @@ find_formula.stanmvreg <- function(x, ...) {
   f <- stats::formula(x)
   mv_formula <- lapply(f, .get_stanmv_formula)
   attr(mv_formula, "is_mv") <- "1"
-  mv_formula
+  .find_formula_return(mv_formula)
 }
 
 
@@ -1161,7 +1266,8 @@ find_formula.MCMCglmm <- function(x, ...) {
   fm <- x$Fixed$formula
   fmr <- x$Random$formula
 
-  .compact_list(list(conditional = fm, random = fmr))
+  f <- .compact_list(list(conditional = fm, random = fmr))
+  .find_formula_return(f)
 }
 
 
@@ -1201,16 +1307,24 @@ find_formula.BFBayesFactor <- function(x, ...) {
     return(NULL)
   }
 
-  .compact_list(list(
+  f <- .compact_list(list(
     conditional = f.cond,
     random = f.random
   ))
+  .find_formula_return(f)
 }
 
 
 
 
 
+# tidymodels --------------------------------------------------------------
+
+#' @export
+find_formula.model_fit <- function(x, ...) {
+  find_formula(x$fit)
+}
+
 
 
 
@@ -1326,7 +1440,8 @@ find_formula.BFBayesFactor <- function(x, ...) {
   )
 
 
-  .compact_list(list(conditional = c.form, zero_inflated = zi.form))
+  f <- .compact_list(list(conditional = c.form, zero_inflated = zi.form))
+  .find_formula_return(f)
 }
 
 
@@ -1349,3 +1464,73 @@ find_formula.BFBayesFactor <- function(x, ...) {
     }
   )
 }
+
+
+.fix_gamm_random_effect <- function(x) {
+  g_in_terms <- length(x) > 1 && x[length(x)] == "g"
+  xr_in_terms <- length(x) > 1 && x[length(x)] == "Xr"
+  x <- x[!(grepl("(Xr\\.\\d|g\\.\\d)", x) | x %in% c("Xr", "g"))]
+  # exceptions, if random effect is named g
+  if (!length(x) && isTRUE(g_in_terms)) {
+    x <- "g"
+  }
+  if (!length(x) && isTRUE(xr_in_terms)) {
+    x <- "Xr"
+  }
+  x
+}
+
+
+.fix_gamm4_random_effect <- function(f) {
+  if (inherits(f, "formula")) {
+    f <- list(f)
+  }
+  len <- length(f)
+  keep <- sapply(f, function(i) {
+    i <- gsub("(~1| | \\|)", "", deparse(i))
+    !any(grepl("(Xr\\.\\d|g\\.\\d)", i) | i %in% c("Xr", "g"))
+  })
+  f <- .compact_list(f[keep])
+  # exceptions, if random effect is named Xr
+  if (!length(f) && len > 1) {
+    f <- list(stats::as.formula("~1 | Xr"))
+  }
+  f
+}
+
+
+
+# Helpers and Methods -----------------------------------------------------
+
+
+.find_formula_return <- function(f) {
+  if (is.null(f)) {
+    return(NULL)
+  }
+  class(f) <- c("insight_formula", class(f))
+  f
+}
+
+
+
+#' @export
+format.insight_formula <- function(x, what = c("conditional", "random"), ...) {
+  # The purpose of this function is to flatten the formula
+
+  # Start by first part (conditional by default)
+  ft <- format(x[[1]])
+
+  # Wrap random in brackets
+  if ("random" %in% names(x)) {
+    x[["random"]] <- paste0("(", format(x[["random"]]), ")")
+  }
+
+  # Add all the components
+  for (part in what[-1]) {
+    if (part %in% names(x)) {
+      ft <- paste0(ft, " + ", format(x[[part]]))
+    }
+  }
+
+  ft
+}
