@@ -1,5 +1,5 @@
 #' @title Parameter table formatting
-#' @name parameters_table
+#' @name format_table
 #'
 #' @description This functions takes a data frame with model parameters as input
 #'   and formats certain columns into a more readable layout (like collapsing
@@ -21,18 +21,20 @@
 #' @examples
 #' if (require("parameters")) {
 #'   x <- model_parameters(lm(Sepal.Length ~ Species * Sepal.Width, data = iris))
-#'   as.data.frame(parameters_table(x))
-#'   as.data.frame(parameters_table(x, p_digits = "scientific"))
+#'   as.data.frame(format_table(x))
+#'   as.data.frame(format_table(x, p_digits = "scientific"))
 #' }
 #' \donttest{
 #' if (require("rstanarm") && require("parameters")) {
 #'   model <- stan_glm(Sepal.Length ~ Species, data = iris, refresh = 0, seed = 123)
 #'   x <- model_parameters(model, ci = c(0.69, 0.89, 0.95))
-#'   as.data.frame(parameters_table(x))
-#' }}
+#'   as.data.frame(format_table(x))
+#' }
+#' }
+#'
 #' @return A data frame.
 #' @export
-parameters_table <- function(x, pretty_names = TRUE, stars = FALSE, digits = 2, ci_width = "auto", ci_brackets = TRUE, ci_digits = 2, p_digits = 3, rope_digits = 2, preserve_attributes = FALSE, ...) {
+format_table <- function(x, pretty_names = TRUE, stars = FALSE, digits = 2, ci_width = "auto", ci_brackets = TRUE, ci_digits = 2, p_digits = 3, rope_digits = 2, preserve_attributes = FALSE, ...) {
 
   # check if user supplied digits attributes
   if (missing(digits)) digits <- .additional_arguments(x, "digits", 2)
@@ -41,17 +43,17 @@ parameters_table <- function(x, pretty_names = TRUE, stars = FALSE, digits = 2,
   if (missing(rope_digits)) rope_digits <- .additional_arguments(x, "rope_digits", 2)
 
   att <- attributes(x)
-  x <- as.data.frame(x)
+  x <- as.data.frame(x, stringsAsFactors = FALSE)
 
 
   # Format parameters names ----
-  if (pretty_names & !is.null(att$pretty_names)) {
+  if (pretty_names && !is.null(att$pretty_names)) {
     # remove strings with NA names
     att$pretty_names <- att$pretty_names[!is.na(names(att$pretty_names))]
     if (length(att$pretty_names) != length(x$Parameter)) {
-      match_pretty_names <- stats::na.omit(match(x$Parameter, names(att$pretty_names)))
+      match_pretty_names <- stats::na.omit(match(names(att$pretty_names), x$Parameter))
       if (length(match_pretty_names)) {
-        x$Parameter[x$Parameter == names(att$pretty_names[match_pretty_names])] <- att$pretty_names[match_pretty_names]
+        x$Parameter[match_pretty_names] <- att$pretty_names[x$Parameter[match_pretty_names]]
       }
     } else {
       match_pretty_names <- att$pretty_names[x$Parameter]
@@ -76,6 +78,10 @@ parameters_table <- function(x, pretty_names = TRUE, stars = FALSE, digits = 2,
   x <- .format_df_columns(x)
 
 
+  # Format special anova columns ----
+  x <- .format_aov_columns(x)
+
+
   # Format frequentist stats ----
   x <- .format_freq_stats(x)
 
@@ -136,17 +142,24 @@ parameters_table <- function(x, pretty_names = TRUE, stars = FALSE, digits = 2,
     x$To <- x$Operator <- x$From <- NULL
   }
 
+  x[] <- lapply(x, as.character)
+
   # restore attributes
   if (isTRUE(preserve_attributes)) {
     attributes(x) <- utils::modifyList(att, attributes(x))
   }
-
   x
 }
 
 
 
 
+#' @rdname format_table
+#' @export
+parameters_table <- format_table
+
+
+
 
 # sub-routines ---------------
 
@@ -161,18 +174,20 @@ parameters_table <- function(x, pretty_names = TRUE, stars = FALSE, digits = 2,
     x$p.value <- format(x$p.value, justify = "left")
   }
 
-  for (stats in c("p_CochransQ", "p_Omnibus", "p_Chi2", "p_Baseline", "p_RMSEA", "p_ROPE")) {
+  for (stats in c("p_CochransQ", "p_Omnibus", "p_Chi2", "p_Baseline", "p_RMSEA", "p_ROPE", "Wu_Hausman_p", "Sargan_p", "p_Omega2", "p_LR")) {
     if (stats %in% names(x)) {
       x[[stats]] <- format_p(x[[stats]], stars = stars, name = NULL, missing = "", digits = p_digits)
       x[[stats]] <- format(x[[stats]], justify = "left")
       p_name <- gsub("(.*)_p$", "\\1", gsub("^p_(.*)", "\\1", stats))
-      names(x)[names(x) == stats] <- paste0("p(", p_name, ")")
+      names(x)[names(x) == stats] <- paste0("p (", p_name, ")")
     }
   }
   x
 }
 
 
+
+
 .format_df_columns <- function(x) {
   # generic df
   if ("df" %in% names(x)) x$df <- format_value(x$df, protect_integers = TRUE)
@@ -180,25 +195,64 @@ parameters_table <- function(x, pretty_names = TRUE, stars = FALSE, digits = 2,
   if ("df_residual" %in% names(x)) x$df_residual <- format_value(x$df_residual, protect_integers = TRUE)
   names(x)[names(x) == "df_residual"] <- "df"
   # df for errors
-  if ("df_error" %in% names(x)) x$df_error <- format_value(x$df_error, protect_integers = TRUE)
-  if (!("df" %in% names(x))) names(x)[names(x) == "df_error"] <- "df"
+  if ("df_error" %in% names(x)) {
+    x$df_error <- format_value(x$df_error, protect_integers = TRUE)
+    if (!("df" %in% names(x))) {
+      names(x)[names(x) == "df_error"] <- "df"
+    } else {
+      names(x)[names(x) == "df_error"] <- "df (error)"
+    }
+  }
   # denominator and numerator df
-  if ("df_num" %in% names(x)) x$df_num <- format_value(x$df_num, protect_integers = TRUE)
-  if ("df_denom" %in% names(x)) x$df_denom <- format_value(x$df_denom, protect_integers = TRUE)
+  if ("df_num" %in% names(x)) {
+    x$df_num <- format_value(x$df_num, protect_integers = TRUE)
+    names(x)[names(x) == "df_num"] <- "df (num.)"
+  }
+  if ("df_denom" %in% names(x)) {
+    x$df_denom <- format_value(x$df_denom, protect_integers = TRUE)
+    names(x)[names(x) == "df_denom"] <- "df (denom.)"
+  }
   x
 }
 
 
 
+
+.format_aov_columns <- function(x) {
+  if ("Deviance_error" %in% names(x)) {
+    x$Deviance_error <- format_value(x$Deviance_error, protect_integers = TRUE)
+    names(x)[names(x) == "Deviance_error"] <- "Deviance (error)"
+  }
+  if ("Power" %in% names(x)) {
+    x$Power <- format_value(x$Power, as_percent = TRUE, digits = 1)
+  }
+  x
+}
+
+
+
+
 #' @importFrom stats na.omit
 .format_freq_stats <- function(x) {
   for (stats in c("t", "Chi2")) {
     if (stats %in% names(x) && "df" %in% names(x)) {
+      if (is.character(x$df)) {
+        x$df[x$df == ""] <- NA_character_
+      }
       df <- stats::na.omit(unique(x$df))
       if (length(df) == 1 && !all(is.infinite(df))) {
         names(x)[names(x) == stats] <- paste0(stats, "(", df, ")")
         x$df <- NULL
       }
+    } else if (stats %in% names(x) && "df_error" %in% names(x)) {
+      if (is.character(x$df_error)) {
+        x$df_error[x$df_error == ""] <- NA_character_
+      }
+      df <- stats::na.omit(unique(x$df_error))
+      if (length(df) == 1 && !all(is.infinite(df))) {
+        names(x)[names(x) == stats] <- paste0(stats, "(", df, ")")
+        x$df_error <- NULL
+      }
     }
   }
 
@@ -221,33 +275,46 @@ parameters_table <- function(x, pretty_names = TRUE, stars = FALSE, digits = 2,
 
 
 
+
 #' @importFrom stats na.omit
 .format_main_ci_columns <- function(x, att, ci_digits, ci_width = "auto", ci_brackets = TRUE) {
   # Main CI
   ci_low <- names(x)[grep("^CI_low", names(x))]
   ci_high <- names(x)[grep("^CI_high", names(x))]
-  if (length(ci_low) >= 1 & length(ci_low) == length(ci_high)) {
+  if (length(ci_low) >= 1 && length(ci_low) == length(ci_high)) {
     if (!is.null(att$ci)) {
       if (length(unique(stats::na.omit(att$ci))) > 1) {
-        ci_colname <- "?% CI"
+        ci_colname <- sprintf("%i%% CI", unique(stats::na.omit(att$ci)) * 100)
       } else {
         ci_colname <- sprintf("%i%% CI", unique(stats::na.omit(att$ci))[1] * 100)
       }
+      x$CI <- NULL
     } else if (!is.null(x$CI)) {
       ci_colname <- sprintf("%i%% CI", unique(stats::na.omit(x$CI))[1] * 100)
       x$CI <- NULL
     } else {
-      ci_colname <- "CI"
+      # all these edge cases... for some objects in "parameters::model_parameters()",
+      # when we have multiple ci-levels, column names can be "CI_low_0.8" or
+      # "CI_low_0.95" etc. - this is handled here, if we have no ci-attribute
+      if (grepl("CI_low_(\\d)\\.(\\d)", ci_low) && grepl("CI_high_(\\d)\\.(\\d)", ci_high)) {
+        ci_levels <- as.numeric(gsub("CI_low_(\\d)\\.(\\d)", "\\1.\\2", ci_low))
+        ci_colname <- sprintf("%i%% CI", unique(stats::na.omit(ci_levels)) * 100)
+        x$CI <- NULL
+      } else {
+        ci_colname <- "CI"
+      }
     }
 
     # Get characters to align the CI
     for (i in 1:length(ci_colname)) {
-      x[ci_colname[i]] <- format_ci(x[[ci_low[i]]], x[[ci_high[i]]], ci = NULL, digits = ci_digits, width = ci_width, brackets = ci_brackets)
+      x[[ci_low[i]]] <- format_ci(x[[ci_low[i]]], x[[ci_high[i]]], ci = NULL, digits = ci_digits, width = ci_width, brackets = ci_brackets)
+      # rename lower CI into final CI column
+      ci_position <- which(names(x) == ci_low[i])
+      colnames(x)[ci_position] <- ci_colname[i]
+      # remove upper CI column
+      ci_position <- which(names(x) == ci_high[i])
+      x[[ci_position]] <- NULL
     }
-    # Replace at initial position
-    ci_position <- which(names(x) == ci_low[1])
-    x <- x[c(names(x)[0:(ci_position - 1)][!names(x)[0:(ci_position - 1)] %in% ci_colname], ci_colname, names(x)[ci_position:(length(names(x)) - 1)][!names(x)[ci_position:(length(names(x)) - 1)] %in% ci_colname])]
-    x <- x[!names(x) %in% c(ci_low, ci_high)]
   }
 
   x
@@ -255,11 +322,12 @@ parameters_table <- function(x, pretty_names = TRUE, stars = FALSE, digits = 2,
 
 
 
+
 #' @importFrom stats na.omit
 .format_other_ci_columns <- function(x, att, ci_digits, ci_width = "auto", ci_brackets = TRUE) {
   other_ci_low <- names(x)[grep("_CI_low$", names(x))]
   other_ci_high <- names(x)[grep("_CI_high$", names(x))]
-  if (length(other_ci_low) >= 1 & length(other_ci_low) == length(other_ci_high)) {
+  if (length(other_ci_low) >= 1 && length(other_ci_low) == length(other_ci_high)) {
     other <- unlist(strsplit(other_ci_low, "_CI_low$"))
 
     # CI percentage
@@ -267,8 +335,10 @@ parameters_table <- function(x, pretty_names = TRUE, stars = FALSE, digits = 2,
       other_ci_colname <- sprintf("%s %i%% CI", other, unique(stats::na.omit(att[[paste0("ci_", other)]])) * 100)
     } else if (!is.null(att$ci)) {
       other_ci_colname <- sprintf("%s %i%% CI", other, unique(stats::na.omit(att$ci)) * 100)
+    } else if (length(other == 1) && paste0(other, "_CI") %in% colnames(x)) {
+      other_ci_colname <- sprintf("%s %i%% CI", other, unique(stats::na.omit(x[[paste0(other, "_CI")]])) * 100)
     } else {
-      other_ci_colname <- paste(other, "CI")
+      other_ci_colname <- paste(other, " CI")
     }
 
     # Get characters to align the CI
@@ -281,6 +351,10 @@ parameters_table <- function(x, pretty_names = TRUE, stars = FALSE, digits = 2,
       other_ci_position <- which(names(x) == other_ci_high[i])
       x[[other_ci_position]] <- NULL
     }
+    # remove columns with CI level
+    for (i in other) {
+      x[[paste0(i, "_CI")]] <- NULL
+    }
   } else {
     other_ci_colname <- c()
   }
@@ -290,6 +364,7 @@ parameters_table <- function(x, pretty_names = TRUE, stars = FALSE, digits = 2,
 
 
 
+
 .format_broom_ci_columns <- function(x, ci_digits, ci_width = "auto", ci_brackets = TRUE) {
   if (!any(grepl("conf.low", names(x), fixed = TRUE))) {
     return(x)
@@ -314,6 +389,7 @@ parameters_table <- function(x, pretty_names = TRUE, stars = FALSE, digits = 2,
 
 
 
+
 .format_rope_columns <- function(x, ci_width = "auto", ci_brackets = TRUE) {
   if (all(c("ROPE_low", "ROPE_high") %in% names(x))) {
     x$ROPE_low <- format_ci(x$ROPE_low, x$ROPE_high, ci = NULL, width = ci_width, brackets = ci_brackets)
@@ -325,6 +401,7 @@ parameters_table <- function(x, pretty_names = TRUE, stars = FALSE, digits = 2,
 
 
 
+
 .format_std_columns <- function(x, other_ci_colname, digits) {
   std_cols <- names(x)[grepl("Std_", names(x))]
   if (length(std_cols) == 0) {
@@ -355,6 +432,7 @@ parameters_table <- function(x, pretty_names = TRUE, stars = FALSE, digits = 2,
 
 
 
+
 .format_bayes_columns <- function(x, stars, rope_digits = 2) {
   # Indices
   if ("BF" %in% names(x)) x$BF <- format_bf(x$BF, name = NULL, stars = stars)
@@ -362,13 +440,14 @@ parameters_table <- function(x, pretty_names = TRUE, stars = FALSE, digits = 2,
   if ("Rhat" %in% names(x)) x$Rhat <- format_value(x$Rhat, digits = 3)
   if ("ESS" %in% names(x)) x$ESS <- format_value(x$ESS, protect_integers = TRUE)
 
-  # ROPE
+  if ("ROPE_Equivalence" %in% names(x)) names(x)[names(x) == "ROPE_Equivalence"] <- "Equivalence (ROPE)"
   if ("ROPE_Percentage" %in% names(x)) {
     x$ROPE_Percentage <- format_rope(x$ROPE_Percentage, name = NULL, digits = rope_digits)
     names(x)[names(x) == "ROPE_Percentage"] <- "% in ROPE"
   }
   x <- .format_rope_columns(x)
 
+
   # Priors
   if ("Prior_Location" %in% names(x)) x$Prior_Location <- format_value(x$Prior_Location, protect_integers = TRUE)
   if ("Prior_Scale" %in% names(x)) x$Prior_Scale <- format_value(x$Prior_Scale, protect_integers = TRUE)
@@ -389,13 +468,12 @@ parameters_table <- function(x, pretty_names = TRUE, stars = FALSE, digits = 2,
     x$Prior_Distribution <- x$Prior_Location <- x$Prior_Scale <- NULL
   }
 
-
-
   x
 }
 
 
 
+
 .format_performance_columns <- function(x) {
   if ("R2_adjusted" %in% names(x)) names(x)[names(x) == "R2_adjusted"] <- "R2 (adj.)"
   if ("R2_conditional" %in% names(x)) names(x)[names(x) == "R2_conditional"] <- "R2 (cond.)"
@@ -403,13 +481,14 @@ parameters_table <- function(x, pretty_names = TRUE, stars = FALSE, digits = 2,
   if ("R2_Tjur" %in% names(x)) names(x)[names(x) == "R2_Tjur"] <- "Tjur's R2"
   if ("R2_Nagelkerke" %in% names(x)) names(x)[names(x) == "R2_Nagelkerke"] <- "Nagelkerke's R2"
   if ("Performance_Score" %in% names(x)) names(x)[names(x) == "Performance_Score"] <- "Performance-Score"
+  if ("Wu_Hausman" %in% names(x)) names(x)[names(x) == "Wu_Hausman"] <- "Wu & Hausman"
+  if ("p(Wu_Hausman)" %in% names(x)) names(x)[names(x) == "p(Wu_Hausman)"] <- "p(Wu & Hausman)"
   x
 }
 
 
 
 
-
 # helper ---------------------
 
 
@@ -424,6 +503,7 @@ parameters_table <- function(x, pretty_names = TRUE, stars = FALSE, digits = 2,
 
 
 
+
 .additional_arguments <- function(x, value, default) {
   args <- attributes(x)$additional_arguments
 
