@@ -11,6 +11,7 @@
 #'      \item{\link[=get_parameters.glmm]{Mixed models} (\pkg{lme4}, \pkg{glmmTMB}, \pkg{GLMMadaptive}, ...)}
 #'      \item{\link[=get_parameters.zeroinfl]{Zero-inflated and hurdle models} (\pkg{pscl}, ...)}
 #'      \item{\link[=get_parameters.betareg]{Models with special components} (\pkg{betareg}, \pkg{MuMIn}, ...)}
+#'      \item{\link[=get_parameters.htest]{Hypothesis tests} (\code{htest})}
 #'    }
 #'
 #' @param verbose Toggle messages and warnings.
@@ -60,9 +61,13 @@ get_parameters.default <- function(x, verbose = TRUE, ...) {
   tryCatch(
     {
       cf <- stats::coef(x)
+      params <- names(cf)
+      if (is.null(params)) {
+        params <- paste(1:length(cf))
+      }
 
       params <- data.frame(
-        Parameter = names(cf),
+        Parameter = params,
         Estimate = unname(cf),
         stringsAsFactors = FALSE,
         row.names = NULL
@@ -102,138 +107,6 @@ get_parameters.data.frame <- function(x, ...) {
 
 
 
-# Survival and censored  models ---------------------------------------------
-
-
-#' @export
-get_parameters.flexsurvreg <- function(x, ...) {
-  cf <- stats::coef(x)
-  params <- data.frame(
-    Parameter = names(cf),
-    Estimate = unname(cf),
-    stringsAsFactors = FALSE,
-    row.names = NULL
-  )
-
-  .remove_backticks_from_parameter_names(params)
-}
-
-
-#' @export
-get_parameters.aareg <- function(x, ...) {
-  sc <- summary(x)
-
-  params <- data.frame(
-    Parameter = rownames(sc$table),
-    Estimate = unname(sc$table[, 2]),
-    stringsAsFactors = FALSE,
-    row.names = NULL
-  )
-
-  .remove_backticks_from_parameter_names(params)
-}
-
-
-#' @importFrom utils stack
-#' @export
-get_parameters.lmodel2 <- function(x, ...) {
-  res <- x$regression.results
-  out <- as.data.frame(cbind(Method = rep(res$Method, 2), utils::stack(res, select = 2:3)))
-  colnames(out) <- c("Component", "Estimate", "Parameter")
-  out[c("Parameter", "Estimate", "Component")]
-}
-
-
-#' @export
-get_parameters.rqs <- function(x, ...) {
-  sc <- suppressWarnings(summary(x))
-
-  if (all(unlist(lapply(sc, is.list)))) {
-    list_sc <- lapply(sc, function(i) {
-      .x <- as.data.frame(stats::coef(i))
-      .x$Parameter <- rownames(.x)
-      .x$tau <- i$tau
-      .x
-    })
-    out <- do.call(rbind, list_sc)
-    params <- data.frame(
-      Parameter = out$Parameter,
-      Estimate = out$coefficients,
-      Component = sprintf("tau (%g)", out$tau),
-      stringsAsFactors = FALSE,
-      row.names = NULL
-    )
-  } else {
-    get_parameters.default(x, ...)
-  }
-  .remove_backticks_from_parameter_names(params)
-}
-
-
-#' @export
-get_parameters.crq <- function(x, ...) {
-  sc <- summary(x)
-
-  if (all(unlist(lapply(sc, is.list)))) {
-    list_sc <- lapply(sc, function(i) {
-      .x <- as.data.frame(i)
-      .x$Parameter <- rownames(.x)
-      .x
-    })
-    out <- do.call(rbind, list_sc)
-    params <- data.frame(
-      Parameter = out$Parameter,
-      Estimate = out$coefficients.Value,
-      Component = sprintf("tau (%g)", out$tau),
-      stringsAsFactors = FALSE,
-      row.names = NULL
-    )
-  } else {
-    params <- data.frame(
-      Parameter = names(sc$coefficients[, 1]),
-      Estimate = unname(sc$coefficients[, 1]),
-      stringsAsFactors = FALSE,
-      row.names = NULL
-    )
-  }
-
-  .remove_backticks_from_parameter_names(params)
-}
-
-#' @export
-get_parameters.crqs <- get_parameters.crq
-
-
-#' @importFrom stats coef
-#' @export
-get_parameters.lqmm <- function(x, ...) {
-  cs <- stats::coef(x)
-
-  if (is.matrix(cs)) {
-    params <- .gather(as.data.frame(cs), names_to = "Component", values_to = "Estimate")
-    params$Component <- sprintf("tau (%s)", params$Component)
-    params$Parameter <- rep(rownames(cs), length.out = nrow(params))
-    params <- params[c("Parameter", "Estimate", "Component")]
-    row.names(params) <- NULL
-  } else {
-    params <- data.frame(
-      Parameter = names(cs),
-      Estimate = unname(cs),
-      stringsAsFactors = FALSE,
-      row.names = NULL
-    )
-  }
-
-  .remove_backticks_from_parameter_names(params)
-}
-
-#' @export
-get_parameters.lqm <- get_parameters.lqmm
-
-
-
-
-
 
 # Special models ---------------------------------------------
 
@@ -246,6 +119,32 @@ get_parameters.rms <- get_parameters.default
 get_parameters.tobit <- get_parameters.default
 
 
+#' @export
+get_parameters.Rchoice <- function(x, ...) {
+  cf <- stats::coef(x)
+  params <- data.frame(
+    Parameter = find_parameters(x, flatten = TRUE),
+    Estimate = as.vector(cf),
+    stringsAsFactors = FALSE,
+    row.names = NULL
+  )
+  .remove_backticks_from_parameter_names(params)
+}
+
+
+#' @export
+get_parameters.btergm <- function(x, ...) {
+  cf <- x@coef
+  params <- data.frame(
+    Parameter = names(cf),
+    Estimate = as.vector(cf),
+    stringsAsFactors = FALSE,
+    row.names = NULL
+  )
+  .remove_backticks_from_parameter_names(params)
+}
+
+
 #' @export
 get_parameters.mediate <- function(x, ...) {
   info <- model_info(x$model.y)
@@ -374,8 +273,7 @@ get_parameters.margins <- function(x, ...) {
 #' @export
 get_parameters.glht <- function(x, ...) {
   s <- summary(x)
-  alt <- switch(
-    x$alternative,
+  alt <- switch(x$alternative,
     two.sided = "==",
     less = ">=",
     greater = "<="
