@@ -23,6 +23,7 @@
 #' @param ci Confidence Interval (CI) level. Default to 0.95 (95\%). Currently only applies to objects of class \code{emmGrid}.
 #' @param ... Currently not used.
 #' @inheritParams get_parameters
+#' @inheritParams get_parameters.emmGrid
 #'
 #' @return A data frame with the model's parameter names and the related test statistic.
 #'
@@ -42,12 +43,42 @@ get_statistic <- function(x, ...) {
 
 #' @rdname get_statistic
 #' @export
-get_statistic.default <- function(x, column_index = 3, ...) {
+get_statistic.default <- function(x, column_index = 3, verbose = TRUE, ...) {
   cs <- stats::coef(summary(x))
 
+  if (column_index > ncol(cs)) {
+    if (isTRUE(verbose)) {
+      warning("Could not access test statistic of model parameters.", call. = FALSE)
+    }
+    return(NULL)
+  }
+
+  # edge cases: check for NULL
+  params <- rownames(cs)
+  if (is.null(params)) {
+    params <- paste(1:nrow(cs))
+  }
+
+  out <- data.frame(
+    Parameter = params,
+    Statistic = as.vector(cs[, column_index]),
+    stringsAsFactors = FALSE,
+    row.names = NULL
+  )
+
+  out <- .remove_backticks_from_parameter_names(out)
+  attr(out, "statistic") <- find_statistic(x)
+  out
+}
+
+
+#' @export
+get_statistic.summary.lm <- function(x, ...) {
+  cs <- stats::coef(x)
+
   out <- data.frame(
     Parameter = rownames(cs),
-    Statistic = as.vector(cs[, column_index]),
+    Statistic = as.vector(cs[, 3]),
     stringsAsFactors = FALSE,
     row.names = NULL
   )
@@ -420,6 +451,28 @@ get_statistic.coxph <- function(x, ...) {
 }
 
 
+#' @export
+get_statistic.coxr <- function(x, ...) {
+  parms <- get_parameters(x)
+  vc <- get_varcov(x)
+  se <- sqrt(diag(vc))
+
+  out <- data.frame(
+    Parameter = parms$Parameter,
+    Statistic = parms$Estimate / se,
+    stringsAsFactors = FALSE,
+    row.names = NULL
+  )
+
+  attr(out, "statistic") <- find_statistic(x)
+  out
+}
+
+
+#' @export
+get_statistic.crr <- get_statistic.coxr
+
+
 #' @importFrom stats vcov
 #' @export
 get_statistic.coxme <- function(x, ...) {
@@ -443,6 +496,23 @@ get_statistic.coxme <- function(x, ...) {
 
 
 
+#' @export
+get_statistic.riskRegression <- function(x, ...) {
+  junk <- utils::capture.output(cs <- stats::coef(x))
+
+  out <- data.frame(
+    Parameter = as.vector(cs[, 1]),
+    Statistic = as.numeric(cs[, "z"]),
+    stringsAsFactors = FALSE,
+    row.names = NULL
+  )
+
+  out <- .remove_backticks_from_parameter_names(out)
+  attr(out, "statistic") <- find_statistic(x)
+  out
+}
+
+
 #' @export
 get_statistic.survreg <- function(x, ...) {
   parms <- get_parameters(x)
@@ -770,12 +840,95 @@ get_statistic.negbinirr <- get_statistic.logitor
 # Other models -------------------------------------------------------
 
 
+#' @export
+get_statistic.Rchoice <- function(x, verbose = TRUE, ...) {
+  cs <- summary(x)$CoefTable
+  out <- data.frame(
+    Parameter = find_parameters(x, flatten = TRUE),
+    Statistic = as.vector(cs[, 3]),
+    stringsAsFactors = FALSE,
+    row.names = NULL
+  )
+
+  attr(out, "statistic") <- find_statistic(x)
+  out
+}
+
+
+#' @export
+get_statistic.garch <- function(x, verbose = TRUE, ...) {
+  cs <- summary(x)$coef
+  out <- data.frame(
+    Parameter = find_parameters(x, flatten = TRUE),
+    Statistic = as.vector(cs[, 3]),
+    stringsAsFactors = FALSE,
+    row.names = NULL
+  )
+
+  attr(out, "statistic") <- find_statistic(x)
+  out
+}
+
+
+#' @export
+get_statistic.ergm <- function(x, verbose = TRUE, ...) {
+  get_statistic.default(x = x, column_index = 4, verbose = verbose, ...)
+}
+
+
+#' @export
+get_statistic.btergm <- function(x, verbose = TRUE, ...) {
+  params <- x@coef
+  bootstraps <- x@boot$t
+
+  # standard error
+  sdev <- sapply(1:ncol(bootstraps), function(i) {
+    cur <- (bootstraps[, i] - params[i])^2
+    sqrt(sum(cur) / length(cur))
+  })
+  stat <- (0 - colMeans(bootstraps)) / sdev
+
+  out <- data.frame(
+    Parameter = names(stat),
+    Statistic = stat,
+    stringsAsFactors = FALSE,
+    row.names = NULL
+  )
+
+  attr(out, "statistic") <- find_statistic(x)
+  out
+}
+
+
 #' @export
 get_statistic.ridgelm <- function(x, ...) {
   NULL
 }
 
 
+#' @export
+get_statistic.lmodel2 <- function(x, ...) {
+  NULL
+}
+
+
+#' @export
+get_statistic.ivFixed <- get_statistic.coxr
+
+
+#' @export
+get_statistic.ivprobit <- function(x, ...) {
+  out <- data.frame(
+    Parameter = x$names,
+    Statistic = as.vector(x$tval),
+    stringsAsFactors = FALSE
+  )
+  out <- .remove_backticks_from_parameter_names(out)
+  attr(out, "statistic") <- find_statistic(x)
+  out
+}
+
+
 #' @export
 get_statistic.HLfit <- function(x, ...) {
   utils::capture.output(s <- summary(x))
@@ -872,8 +1025,7 @@ get_statistic.mle <- get_statistic.mle2
 #' @export
 get_statistic.glht <- function(x, ...) {
   s <- summary(x)
-  alt <- switch(
-    x$alternative,
+  alt <- switch(x$alternative,
     two.sided = "==",
     less = ">=",
     greater = "<="
@@ -1293,6 +1445,35 @@ get_statistic.rq <- function(x, ...) {
   out
 }
 
+
+#' @export
+get_statistic.rqs <- function(x, ...) {
+  stat <- tryCatch(
+    {
+      s <- suppressWarnings(summary(x, covariance = TRUE))
+      cs <- do.call(rbind, lapply(s, stats::coef))
+      cs[, "t value"]
+    },
+    error = function(e) {
+      NULL
+    }
+  )
+
+  params <- get_parameters(x)
+
+  out <- data.frame(
+    Parameter = params$Parameter,
+    Statistic = stat,
+    Component = params$Component,
+    stringsAsFactors = FALSE,
+    row.names = NULL
+  )
+
+  attr(out, "statistic") <- find_statistic(x)
+  out
+}
+
+
 #' @export
 get_statistic.crq <- function(x, ...) {
   sc <- summary(x)
@@ -1740,3 +1921,16 @@ get_statistic.bife <- function(x, ...) {
 get_statistic.mediate <- function(x, ...) {
   NULL
 }
+
+
+#' @export
+get_statistic.coeftest <- function(x, ...) {
+  out <- data.frame(
+    Parameter = row.names(x),
+    Statistic = x[, 3],
+    stringsAsFactors = FALSE,
+    row.names = NULL
+  )
+  attr(out, "statistic") <- find_statistic(x)
+  out
+}
