@@ -19,6 +19,7 @@
 #'   applies to models of class \code{mixor}.
 #' @param complete Logical, if \code{TRUE}, for \code{aov}, returns the full
 #'   variance-covariance matrix.
+#' @param verbose Toggle warnings.
 #' @param ... Currently not used.
 #'
 #' @note \code{get_varcov()} tries to return the nearest positive definite matrix
@@ -40,18 +41,11 @@ get_varcov <- function(x, ...) {
 # Default models ----------------------------------------------------
 
 
+#' @rdname get_varcov
 #' @export
-get_varcov.default <- function(x, ...) {
+get_varcov.default <- function(x, verbose = TRUE, ...) {
   vc <- suppressWarnings(stats::vcov(x))
-
-  if (.is_negativ_matrix(vc)) {
-    vc <- .fix_negative_matrix(vc)
-  }
-
-  # fix possible missings due to rank deficient model matrix
-  vc <- .fix_rank_deficiency(vc)
-
-  .remove_backticks_from_matrix_names(as.matrix(vc))
+  .process_vcov(vc, verbose)
 }
 
 
@@ -83,30 +77,21 @@ get_varcov.mlm <- function(x, ...) {
 
 #' @rdname get_varcov
 #' @export
-get_varcov.betareg <- function(x, component = c("conditional", "precision", "all"), ...) {
+get_varcov.betareg <- function(x, component = c("conditional", "precision", "all"), verbose = TRUE, ...) {
   component <- match.arg(component)
 
-  vc <- switch(
-    component,
+  vc <- switch(component,
     "conditional" = stats::vcov(object = x, model = "mean"),
     "precision" = stats::vcov(object = x, model = "precision"),
     stats::vcov(object = x)
   )
-
-  if (.is_negativ_matrix(vc)) {
-    vc <- .fix_negative_matrix(vc)
-  }
-
-  # fix possible missings due to rank deficient model matrix
-  vc <- .fix_rank_deficiency(vc)
-
-  .remove_backticks_from_matrix_names(as.matrix(vc))
+  .process_vcov(vc, verbose)
 }
 
 
 #' @rdname get_varcov
 #' @export
-get_varcov.DirichletRegModel <- function(x, component = c("conditional", "precision", "all"), ...) {
+get_varcov.DirichletRegModel <- function(x, component = c("conditional", "precision", "all"), verbose = TRUE, ...) {
   component <- match.arg(component)
   if (x$parametrization == "common") {
     vc <- stats::vcov(x)
@@ -123,15 +108,7 @@ get_varcov.DirichletRegModel <- function(x, component = c("conditional", "precis
       vc <- stats::vcov(x)
     }
   }
-
-  if (.is_negativ_matrix(vc)) {
-    vc <- .fix_negative_matrix(vc)
-  }
-
-  # fix possible missings due to rank deficient model matrix
-  vc <- .fix_rank_deficiency(vc)
-
-  .remove_backticks_from_matrix_names(as.matrix(vc))
+  .process_vcov(vc, verbose)
 }
 
 
@@ -150,8 +127,7 @@ get_varcov.clm2 <- function(x, component = c("all", "conditional", "scale"), ...
     vc <- .fix_negative_matrix(vc)
   }
 
-  range <- switch(
-    component,
+  range <- switch(component,
     "all" = 1:(n_scale + n_intercepts + n_location),
     "conditional" = 1:(n_intercepts + n_location),
     "scale" = (1 + n_intercepts + n_location):(n_scale + n_intercepts + n_location)
@@ -175,18 +151,10 @@ get_varcov.glmx <- function(x, component = c("all", "conditional", "extra"), ...
   vc <- stats::vcov(object = x)
 
   if (component != "all") {
-    keep <- match(insight::find_parameters(x)[[component]], rownames(vc))
+    keep <- match(find_parameters(x)[[component]], rownames(vc))
     vc <- vc[keep, keep, drop = FALSE]
   }
-
-  if (.is_negativ_matrix(vc)) {
-    vc <- .fix_negative_matrix(vc)
-  }
-
-  # fix possible missings due to rank deficient model matrix
-  vc <- .fix_rank_deficiency(vc)
-
-  .remove_backticks_from_matrix_names(as.matrix(vc))
+  .process_vcov(vc)
 }
 
 
@@ -199,15 +167,7 @@ get_varcov.truncreg <- function(x, component = c("conditional", "all"), ...) {
   if (component == "conditional") {
     vc <- vc[1:(nrow(vc) - 1), 1:(ncol(vc) - 1), drop = FALSE]
   }
-
-  if (.is_negativ_matrix(vc)) {
-    vc <- .fix_negative_matrix(vc)
-  }
-
-  # fix possible missings due to rank deficient model matrix
-  vc <- .fix_rank_deficiency(vc)
-
-  .remove_backticks_from_matrix_names(as.matrix(vc))
+  .process_vcov(vc)
 }
 
 
@@ -221,15 +181,7 @@ get_varcov.gamlss <- function(x, component = c("conditional", "all"), ...) {
     cond_pars <- length(find_parameters(x)$conditional)
     vc <- as.matrix(vc)[1:cond_pars, 1:cond_pars, drop = FALSE]
   }
-
-  if (.is_negativ_matrix(vc)) {
-    vc <- .fix_negative_matrix(vc)
-  }
-
-  # fix possible missings due to rank deficient model matrix
-  vc <- .fix_rank_deficiency(vc)
-
-  .remove_backticks_from_matrix_names(as.matrix(vc))
+  .process_vcov(vc)
 }
 
 
@@ -245,22 +197,13 @@ get_varcov.gamlss <- function(x, component = c("conditional", "all"), ...) {
 get_varcov.hurdle <- function(x, component = c("conditional", "zero_inflated", "zi", "all"), ...) {
   component <- match.arg(component)
 
-  vc <- switch(
-    component,
+  vc <- switch(component,
     "conditional" = stats::vcov(object = x, model = "count"),
     "zi" = ,
     "zero_inflated" = stats::vcov(object = x, model = "zero"),
     stats::vcov(object = x)
   )
-
-  if (.is_negativ_matrix(vc)) {
-    vc <- .fix_negative_matrix(vc)
-  }
-
-  # fix possible missings due to rank deficient model matrix
-  vc <- .fix_rank_deficiency(vc)
-
-  .remove_backticks_from_matrix_names(as.matrix(vc))
+  .process_vcov(vc)
 }
 
 #' @export
@@ -282,22 +225,13 @@ get_varcov.zcpglm <- function(x, component = c("conditional", "zero_inflated", "
   tweedie <- which(grepl("^tw_", rownames(vc)))
   zero <- which(grepl("^zero_", rownames(vc)))
 
-  vc <- switch(
-    component,
+  vc <- switch(component,
     "conditional" = vc[tweedie, tweedie, drop = FALSE],
     "zi" = ,
     "zero_inflated" = vc[zero, zero, drop = FALSE],
     vc[c(tweedie, zero), c(tweedie, zero), drop = FALSE]
   )
-
-  if (.is_negativ_matrix(vc)) {
-    vc <- .fix_negative_matrix(vc)
-  }
-
-  # fix possible missings due to rank deficient model matrix
-  vc <- .fix_rank_deficiency(vc)
-
-  .remove_backticks_from_matrix_names(as.matrix(vc))
+  .process_vcov(vc)
 }
 
 
@@ -314,22 +248,13 @@ get_varcov.zcpglm <- function(x, component = c("conditional", "zero_inflated", "
 get_varcov.MixMod <- function(x, component = c("conditional", "zero_inflated", "zi", "all"), ...) {
   component <- match.arg(component)
 
-  vc <- switch(
-    component,
+  vc <- switch(component,
     "conditional" = stats::vcov(x, parm = "fixed-effects"),
     "zi" = ,
     "zero_inflated" = stats::vcov(x, parm = "zero_part"),
     stats::vcov(x)
   )
-
-  if (.is_negativ_matrix(vc)) {
-    vc <- .fix_negative_matrix(vc)
-  }
-
-  # fix possible missings due to rank deficient model matrix
-  vc <- .fix_rank_deficiency(vc)
-
-  .remove_backticks_from_matrix_names(as.matrix(vc))
+  .process_vcov(vc)
 }
 
 
@@ -338,23 +263,14 @@ get_varcov.MixMod <- function(x, component = c("conditional", "zero_inflated", "
 get_varcov.glmmTMB <- function(x, component = c("conditional", "zero_inflated", "zi", "dispersion", "all"), ...) {
   component <- match.arg(component)
 
-  vc <- switch(
-    component,
+  vc <- switch(component,
     "conditional" = stats::vcov(x)[["cond"]],
     "zi" = ,
     "zero_inflated" = stats::vcov(x)[["zi"]],
     "dispersion" = stats::vcov(x)[["disp"]],
     stats::vcov(x, full = TRUE)
   )
-
-  if (.is_negativ_matrix(vc)) {
-    vc <- .fix_negative_matrix(vc)
-  }
-
-  # fix possible missings due to rank deficient model matrix
-  vc <- .fix_rank_deficiency(vc)
-
-  .remove_backticks_from_matrix_names(as.matrix(vc))
+  .process_vcov(vc)
 }
 
 
@@ -373,15 +289,7 @@ get_varcov.brmsfit <- function(x, component = c("conditional", "zero_inflated",
   params <- gsub("^b_", "", params)
 
   vc <- stats::vcov(x)[params, params, drop = FALSE]
-
-  if (.is_negativ_matrix(vc)) {
-    vc <- .fix_negative_matrix(vc)
-  }
-
-  # fix possible missings due to rank deficient model matrix
-  vc <- .fix_rank_deficiency(vc)
-
-  .remove_backticks_from_matrix_names(as.matrix(vc))
+  .process_vcov(vc)
 }
 
 
@@ -451,18 +359,15 @@ get_varcov.mediate <- function(x, ...) {
 #' @export
 get_varcov.aov <- function(x, complete = FALSE, ...) {
   vc <- suppressWarnings(stats::vcov(x, complete = complete))
-
-  if (.is_negativ_matrix(vc)) {
-    vc <- .fix_negative_matrix(vc)
-  }
-
-  # fix possible missings due to rank deficient model matrix
-  vc <- .fix_rank_deficiency(vc)
-
-  .remove_backticks_from_matrix_names(as.matrix(vc))
+  .process_vcov(vc)
 }
 
 
+#' @export
+get_varcov.ivFixed <- function(x, ...) {
+  .process_vcov(x$vcov)
+}
+
 
 #' @export
 get_varcov.averaging <- function(x, ...) {
@@ -481,15 +386,16 @@ get_varcov.robmixglm <- function(x, ...) {
   vc <- x$fit@vcov[1:np, 1:np, drop = FALSE]
 
   dimnames(vc) <- list(params, params)
+  .process_vcov(vc)
+}
 
-  if (.is_negativ_matrix(vc)) {
-    vc <- .fix_negative_matrix(vc)
-  }
 
-  # fix possible missings due to rank deficient model matrix
-  vc <- .fix_rank_deficiency(vc)
-
-  .remove_backticks_from_matrix_names(as.matrix(vc))
+#' @export
+get_varcov.Rchoice <- function(x, ...) {
+  vc <- stats::vcov(x)
+  params <- find_parameters(x, flatten = TRUE)
+  dimnames(vc) <- list(params, params)
+  .process_vcov(vc)
 }
 
 
@@ -506,6 +412,15 @@ get_varcov.rq <- function(x, ...) {
 }
 
 
+#' @export
+get_varcov.crr <- function(x, ...) {
+  vc <- as.matrix(x$var)
+  params <- find_parameters(x, flatten = TRUE)
+  dimnames(vc) <- list(params, params)
+  .process_vcov(vc)
+}
+
+
 #' @export
 get_varcov.crq <- function(x, ...) {
   sc <- summary(x, covariance = TRUE)
@@ -533,20 +448,15 @@ get_varcov.crq <- function(x, ...) {
 #' @export
 get_varcov.nlrq <- get_varcov.rq
 
+#' @export
+get_varcov.rqs <- get_varcov.rq
+
 
 #' @export
 get_varcov.flexsurvreg <- function(x, ...) {
   pars <- find_parameters(x, flatten = TRUE)
   vc <- as.matrix(stats::vcov(x))[pars, pars, drop = FALSE]
-
-  if (.is_negativ_matrix(vc)) {
-    vc <- .fix_negative_matrix(vc)
-  }
-
-  # fix possible missings due to rank deficient model matrix
-  vc <- .fix_rank_deficiency(vc)
-
-  .remove_backticks_from_matrix_names(as.matrix(vc))
+  .process_vcov(vc)
 }
 
 
@@ -563,30 +473,14 @@ get_varcov.afex_aov <- function(x, ...) {
 #' @export
 get_varcov.mixed <- function(x, ...) {
   vc <- as.matrix(stats::vcov(x$full_model))
-
-  if (.is_negativ_matrix(vc)) {
-    vc <- .fix_negative_matrix(vc)
-  }
-
-  # fix possible missings due to rank deficient model matrix
-  vc <- .fix_rank_deficiency(vc)
-
-  .remove_backticks_from_matrix_names(as.matrix(vc))
+  .process_vcov(vc)
 }
 
 
 #' @export
 get_varcov.cpglmm <- function(x, ...) {
   vc <- as.matrix(x@vcov)
-
-  if (.is_negativ_matrix(vc)) {
-    vc <- .fix_negative_matrix(vc)
-  }
-
-  # fix possible missings due to rank deficient model matrix
-  vc <- .fix_rank_deficiency(vc)
-
-  .remove_backticks_from_matrix_names(as.matrix(vc))
+  .process_vcov(vc)
 }
 
 #' @export
@@ -597,15 +491,7 @@ get_varcov.cpglm <- get_varcov.cpglmm
 #' @export
 get_varcov.cglm <- function(x, ...) {
   vc <- as.matrix(x$var)
-
-  if (.is_negativ_matrix(vc)) {
-    vc <- .fix_negative_matrix(vc)
-  }
-
-  # fix possible missings due to rank deficient model matrix
-  vc <- .fix_rank_deficiency(vc)
-
-  .remove_backticks_from_matrix_names(as.matrix(vc))
+  .process_vcov(vc)
 }
 
 
@@ -613,15 +499,7 @@ get_varcov.cglm <- function(x, ...) {
 #' @export
 get_varcov.mle2 <- function(x, ...) {
   vc <- as.matrix(x@vcov)
-
-  if (.is_negativ_matrix(vc)) {
-    vc <- .fix_negative_matrix(vc)
-  }
-
-  # fix possible missings due to rank deficient model matrix
-  vc <- .fix_rank_deficiency(vc)
-
-  .remove_backticks_from_matrix_names(as.matrix(vc))
+  .process_vcov(vc)
 }
 
 
@@ -636,15 +514,7 @@ get_varcov.mixor <- function(x, effects = c("all", "fixed", "random"), ...) {
   effects <- match.arg(effects)
   params <- find_parameters(x, effects = effects, flatten = TRUE)
   vc <- as.matrix(stats::vcov(x))[params, params, drop = FALSE]
-
-  if (.is_negativ_matrix(vc)) {
-    vc <- .fix_negative_matrix(vc)
-  }
-
-  # fix possible missings due to rank deficient model matrix
-  vc <- .fix_rank_deficiency(vc)
-
-  .remove_backticks_from_matrix_names(as.matrix(vc))
+  .process_vcov(vc)
 }
 
 
@@ -655,15 +525,7 @@ get_varcov.glmm <- get_varcov.mixor
 #' @export
 get_varcov.gamm <- function(x, ...) {
   vc <- stats::vcov(x$gam)
-
-  if (.is_negativ_matrix(vc)) {
-    vc <- .fix_negative_matrix(vc)
-  }
-
-  # fix possible missings due to rank deficient model matrix
-  vc <- .fix_rank_deficiency(vc)
-
-  .remove_backticks_from_matrix_names(as.matrix(vc))
+  .process_vcov(vc)
 }
 
 
@@ -701,15 +563,7 @@ get_varcov.lqm <- get_varcov.lqmm
 get_varcov.list <- function(x, ...) {
   if ("gam" %in% names(x)) {
     vc <- stats::vcov(x$gam)
-
-    if (.is_negativ_matrix(vc)) {
-      vc <- .fix_negative_matrix(vc)
-    }
-
-    # fix possible missings due to rank deficient model matrix
-    vc <- .fix_rank_deficiency(vc)
-
-    .remove_backticks_from_matrix_names(as.matrix(vc))
+    .process_vcov(vc)
   }
 }
 
@@ -717,45 +571,21 @@ get_varcov.list <- function(x, ...) {
 #' @export
 get_varcov.BBmm <- function(x, ...) {
   vc <- x$fixed.vcov
-
-  if (.is_negativ_matrix(vc)) {
-    vc <- .fix_negative_matrix(vc)
-  }
-
-  # fix possible missings due to rank deficient model matrix
-  vc <- .fix_rank_deficiency(vc)
-
-  .remove_backticks_from_matrix_names(as.matrix(vc))
+  .process_vcov(vc)
 }
 
 
 #' @export
 get_varcov.BBreg <- function(x, ...) {
   vc <- x$vcov
-
-  if (.is_negativ_matrix(vc)) {
-    vc <- .fix_negative_matrix(vc)
-  }
-
-  # fix possible missings due to rank deficient model matrix
-  vc <- .fix_rank_deficiency(vc)
-
-  .remove_backticks_from_matrix_names(as.matrix(vc))
+  .process_vcov(vc)
 }
 
 
 #' @export
 get_varcov.feis <- function(x, ...) {
   vc <- x$vcov
-
-  if (.is_negativ_matrix(vc)) {
-    vc <- .fix_negative_matrix(vc)
-  }
-
-  # fix possible missings due to rank deficient model matrix
-  vc <- .fix_rank_deficiency(vc)
-
-  .remove_backticks_from_matrix_names(as.matrix(vc))
+  .process_vcov(vc)
 }
 
 
@@ -765,15 +595,7 @@ get_varcov.glimML <- function(x, ...) {
     stop("Package 'aod' required for this function to work. Please install it.")
   }
   vc <- aod::vcov(x)
-
-  if (.is_negativ_matrix(vc)) {
-    vc <- .fix_negative_matrix(vc)
-  }
-
-  # fix possible missings due to rank deficient model matrix
-  vc <- .fix_rank_deficiency(vc)
-
-  .remove_backticks_from_matrix_names(as.matrix(vc))
+  .process_vcov(vc)
 }
 
 
@@ -783,15 +605,7 @@ get_varcov.vglm <- function(x, ...) {
     stop("Package 'VGAM' required for this function to work. Please install it.")
   }
   vc <- VGAM::vcov(x)
-
-  if (.is_negativ_matrix(vc)) {
-    vc <- .fix_negative_matrix(vc)
-  }
-
-  # fix possible missings due to rank deficient model matrix
-  vc <- .fix_rank_deficiency(vc)
-
-  .remove_backticks_from_matrix_names(as.matrix(vc))
+  .process_vcov(vc)
 }
 
 
@@ -802,15 +616,7 @@ get_varcov.vgam <- get_varcov.vglm
 #' @export
 get_varcov.geeglm <- function(x, ...) {
   vc <- summary(x)$cov.unscaled
-
-  if (.is_negativ_matrix(vc)) {
-    vc <- .fix_negative_matrix(vc)
-  }
-
-  # fix possible missings due to rank deficient model matrix
-  vc <- .fix_rank_deficiency(vc)
-
-  .remove_backticks_from_matrix_names(as.matrix(vc))
+  .process_vcov(vc)
 }
 
 
@@ -818,30 +624,14 @@ get_varcov.geeglm <- function(x, ...) {
 get_varcov.tobit <- function(x, ...) {
   coef_names <- find_parameters(x, flatten = TRUE)
   vc <- stats::vcov(x)[coef_names, coef_names, drop = FALSE]
-
-  if (.is_negativ_matrix(vc)) {
-    vc <- .fix_negative_matrix(vc)
-  }
-
-  # fix possible missings due to rank deficient model matrix
-  vc <- .fix_rank_deficiency(vc)
-
-  .remove_backticks_from_matrix_names(as.matrix(vc))
+  .process_vcov(vc)
 }
 
 
 #' @export
 get_varcov.lmRob <- function(x, ...) {
   vc <- x$cov
-
-  if (.is_negativ_matrix(vc)) {
-    vc <- .fix_negative_matrix(vc)
-  }
-
-  # fix possible missings due to rank deficient model matrix
-  vc <- .fix_rank_deficiency(vc)
-
-  .remove_backticks_from_matrix_names(as.matrix(vc))
+  .process_vcov(vc)
 }
 
 
@@ -850,18 +640,17 @@ get_varcov.glmRob <- get_varcov.lmRob
 
 
 
+#' @export
+get_varcov.coxr <- function(x, ...) {
+  vc <- x$var
+  .process_vcov(vc)
+}
+
+
 #' @export
 get_varcov.gee <- function(x, ...) {
   vc <- x$naive.variance
-
-  if (.is_negativ_matrix(vc)) {
-    vc <- .fix_negative_matrix(vc)
-  }
-
-  # fix possible missings due to rank deficient model matrix
-  vc <- .fix_rank_deficiency(vc)
-
-  .remove_backticks_from_matrix_names(as.matrix(vc))
+  .process_vcov(vc)
 }
 
 
@@ -877,6 +666,16 @@ get_varcov.LORgee <- get_varcov.gee
 # helper-functions -----------------------------------------------------
 
 
+.process_vcov <- function(vc, verbose = TRUE) {
+  if (.is_negativ_matrix(vc)) {
+    vc <- .fix_negative_matrix(vc)
+  }
+  # fix possible missings due to rank deficient model matrix
+  vc <- .fix_rank_deficiency(vc, verbose)
+  .remove_backticks_from_matrix_names(as.matrix(vc))
+}
+
+
 .is_negativ_matrix <- function(x) {
   if (is.matrix(x) && (nrow(x) == ncol(x))) {
     rv <- tryCatch(
@@ -906,10 +705,22 @@ get_varcov.LORgee <- get_varcov.gee
 }
 
 
-.fix_rank_deficiency <- function(m) {
+.fix_rank_deficiency <- function(m, verbose = TRUE) {
   if (anyNA(m)) {
-    warning("Model matrix is rank deficient. Some variance-covariance parameters are missing.", call. = FALSE)
-    m <- m[!is.na]
+    if (isTRUE(verbose)) {
+      warning("Model matrix is rank deficient. Some variance-covariance parameters are missing.", call. = FALSE)
+    }
+    mm <- m[!is.na(m)]
+    if (!is.matrix(mm)) {
+      mm <- matrix(mm, nrow = sqrt(length(mm)))
+      na_cols <- apply(m, 2, function(i) all(is.na(i)))
+      rownames(mm) <- rownames(m)[!na_cols]
+      colnames(mm) <- rownames(m)[!na_cols]
+      attr(mm, "na_columns_name") <- na_cols[na_cols]
+      attr(mm, "na_columns_index") <- which(na_cols)
+      attr(mm, "rank_deficient") <- TRUE
+    }
+    m <- mm
   }
   m
 }
