@@ -100,6 +100,7 @@ is_regression_model <- function(x) {
     "crch",
     "crq",
     "crqs",
+    "crr",
     "dglm",
     "DirichletRegModel",
     "drc",
@@ -239,6 +240,7 @@ is_regression_model <- function(x) {
     "psm",
     "probitmfx",
     "rankFD",
+    "Rchoice",
     "rdrobust",
     "ridgelm",
     "riskRegression",
@@ -280,6 +282,7 @@ is_regression_model <- function(x) {
     "tobit",
     "trendPMCMR",
     "truncreg",
+    "varest",
     "vgam",
     "vglm",
     "wbm",
@@ -297,4 +300,4 @@ is_regression_model <- function(x) {
   }
 
   out
-}
\ No newline at end of file
+}
