@@ -41,6 +41,7 @@ supported_models <- function() {
     "afex_aov",
     "aov",
     "aovlist",
+    "Anova.mlm",
     "Arima",
     "averaging",
     "bamlss",
@@ -64,6 +65,7 @@ supported_models <- function() {
     "brglm",
     "brmsfit",
     "brmultinom",
+    "btergm",
     "censReg",
     "cgam",
     "cgamm",
@@ -73,19 +75,24 @@ supported_models <- function() {
     "clmm",
     "clmm2",
     "clogit",
+    "coeftest",
     "complmrob",
     "coxme",
     "coxph",
     "coxph.penal",
+    "coxr",
     "cpglm",
     "cpglmm",
     "crch",
     "crq",
     "crqs",
+    "crr",
     "DirichletRegModel",
+    "ergm",
     "feis",
     "felm",
     "feglm",
+    "fitdistr",
     "fixest",
     "flexsurvreg",
     "gam",
@@ -93,6 +100,7 @@ supported_models <- function() {
     "gamlss",
     "gamm",
     "gamm4",
+    "garch",
     "gbm",
     "gee",
     "geeglm",
@@ -112,8 +120,10 @@ supported_models <- function() {
     "HLfit",
     "htest",
     "hurdle",
+    "ivFixed",
     "iv_robust",
     "ivreg",
+    "ivprobit",
     "lavaan",
     "lm",
     "lm_robust",
@@ -122,6 +132,7 @@ supported_models <- function() {
     "lmRob",
     "lmerMod",
     "lmerModLmerTest",
+    "lmodel2",
     "logitmfx",
     "logitor",
     "logistf",
@@ -164,7 +175,9 @@ supported_models <- function() {
     "polr",
     "psm",
     "probitmfx",
+    "Rchoice",
     "ridgelm",
+    "riskRegression",
     "rlm",
     "rlmerMod",
     "RM",
@@ -172,6 +185,7 @@ supported_models <- function() {
     "rma.uni",
     "robmixglm",
     "rq",
+    "rqs",
     "rqss",
     "scam",
     "sem",
@@ -179,6 +193,7 @@ supported_models <- function() {
     "speedglm",
     "stanmvreg",
     "stanreg",
+    "summary.lm",
     "survfit",
     "survreg",
     "svyglm",
