@@ -16,7 +16,7 @@
 #' data(mtcars)
 #' m <- lm(mpg ~ wt + cyl + vs, data = mtcars)
 #' n_obs(m)
-#' @importFrom stats model.frame nobs
+#' @importFrom stats model.frame nobs family
 #' @export
 n_obs <- function(x, ...) {
   UseMethod("n_obs")
@@ -30,6 +30,20 @@ n_obs.default <- function(x, ...) {
     class(x) <- c(class(x), c("glm", "lm"))
   }
 
+  is_binomial <- tryCatch(
+    {
+      fam <- stats::family(x)
+      fam$family == "binomial"
+    },
+    error = function(e) {
+      FALSE
+    }
+  )
+
+  if (isTRUE(is_binomial)) {
+    return(n_obs.glm(x, ...))
+  }
+
   tryCatch(
     {
       stats::nobs(x)
@@ -41,6 +55,36 @@ n_obs.default <- function(x, ...) {
 }
 
 
+#' @importFrom stats nobs formula
+#' @export
+n_obs.glm <- function(x, ...) {
+  is_binomial <- tryCatch(
+    {
+      fam <- stats::family(x)
+      fam$family == "binomial"
+    },
+    error = function(e) {
+      FALSE
+    }
+  )
+  .nobs <- stats::nobs(x)
+
+  if (isTRUE(is_binomial)) {
+    resp <- deparse(stats::formula(x)[[2]])
+    if (grepl("^cbind\\(", resp)) {
+      trials <- trimws(sub("cbind\\((.*),(.*)\\)", "\\2", resp))
+      resp_data <- get_response(x)
+      if (grepl("-", trials, fixed = TRUE)) {
+        .nobs <- sum(resp_data[[2]])
+      } else {
+        .nobs <- sum(resp_data)
+      }
+    }
+  }
+
+  .nobs
+}
+
 #' @export
 n_obs.censReg <- n_obs.default
 
@@ -65,6 +109,11 @@ n_obs.gamm <- function(x, ...) {
 }
 
 
+#' @export
+n_obs.lavaan <- function(x, ...) {
+  x@SampleStats@ntotal
+}
+
 
 #' @export
 n_obs.merModList <- function(x, ...) {
@@ -73,6 +122,13 @@ n_obs.merModList <- function(x, ...) {
 
 
 
+#' @export
+n_obs.summary.lm <- function(x, ...) {
+  length(x$residuals)
+}
+
+
+
 #' @export
 n_obs.mediate <- function(x, ...) {
   x$nobs
@@ -80,6 +136,13 @@ n_obs.mediate <- function(x, ...) {
 
 
 
+#' @export
+n_obs.garch <- function(x, ...) {
+  x$n.used
+}
+
+
+
 #' @export
 n_obs.bayesx <- function(x, ...) {
   length(x$response)
@@ -94,6 +157,13 @@ n_obs.flexsurvreg <- function(x, ...) {
 
 
 
+#' @export
+n_obs.ivprobit <- function(x, ...) {
+  nrow(x$mr1)
+}
+
+
+
 #' @export
 n_obs.bamlss <- function(x, ...) {
   nrow(x$model.frame)
@@ -101,6 +171,13 @@ n_obs.bamlss <- function(x, ...) {
 
 
 
+#' @export
+n_obs.coeftest <- function(x, ...) {
+  attributes(x)$nobs
+}
+
+
+
 #' @export
 n_obs.lmRob <- function(x, ...) {
   length(x$fitted.values)
@@ -136,6 +213,13 @@ n_obs.LORgee <- function(x, ...) {
 
 
 
+#' @export
+n_obs.crr <- function(x, ...) {
+  x$n
+}
+
+
+
 #' @export
 n_obs.mcmc <- function(x, ...) {
   nrow(as.data.frame(x))
@@ -238,6 +322,13 @@ n_obs.cpglmm <- function(x, ...) {
 
 
 
+#' @export
+n_obs.lmodel2 <- function(x, ...) {
+  nrow(get_data(x))
+}
+
+
+
 #' @export
 n_obs.cpglm <- function(x, ...) {
   nrow(x$model.frame)
@@ -255,7 +346,8 @@ n_obs.rq <- function(x, ...) {
   length(x$fitted.values)
 }
 
-
+#' @export
+n_obs.ivFixed <- n_obs.rq
 
 #' @export
 n_obs.BBreg <- function(x, ...) {
@@ -280,6 +372,18 @@ n_obs.crq <- function(x, ...) {
 n_obs.crqs <- n_obs.crq
 
 
+#' @export
+n_obs.comprisk <- function(x, ...) {
+  x$n
+}
+
+
+#' @export
+n_obs.riskRegression <- function(x, ...) {
+  nrow(x$response)
+}
+
+
 #' @export
 n_obs.MANOVA <- function(x, ...) {
   nrow(x$input$data)
@@ -325,6 +429,11 @@ n_obs.coxph <- n_obs.aareg
 n_obs.coxme <- n_obs.aareg
 
 
+#' @export
+n_obs.coxr <- function(x, ...) {
+  nrow(x$y)
+}
+
 
 #' @export
 n_obs.felm <- function(x, ...) {
@@ -424,6 +533,13 @@ n_obs.wbgee <- function(x, ...) {
 }
 
 
+#' @export
+n_obs.Rchoice <- function(x, ...) {
+  nrow(x$mf)
+}
+
+
+
 
 
 # mfx models --------------------------------------
