@@ -21,6 +21,13 @@ if (.runThisTest) {
       expect_false(model_info(m)$is_linear)
     })
 
+    test_that("n_parameters", {
+      expect_equal(n_parameters(m), 6)
+      expect_equal(n_parameters(m2), 6)
+      expect_equal(n_parameters(m, effects = "random"), 2)
+      expect_equal(n_parameters(m2, effects = "random"), 1)
+    })
+
     test_that("find_predictors", {
       expect_identical(
         find_predictors(m, effects = "fixed")$conditional,
@@ -226,7 +233,7 @@ if (.runThisTest) {
         component = "cond", effects = "random"
       )), "persons")
       expect_identical(colnames(get_data(m, component = "dispersion")), "count")
-      expect_null(get_data(m, component = "dispersion", effects = "random"))
+      expect_null(suppressWarnings(get_data(m, component = "dispersion", effects = "random")))
       expect_identical(
         colnames(get_data(m3)),
         c("incidence", "size", "period", "herd")
